@@ -36,7 +36,7 @@ class UnifiedOrderExecutionDemo:
     """Demonstration of unified order execution across multiple markets."""
     
     def __init__(self):
-        """Initialize the demo with mock components."""
+        """Initialize the demo with real components using environment variables."""
         self.market_manager = None
         self.risk_manager = None
         self.unified_order_manager = None
@@ -45,8 +45,8 @@ class UnifiedOrderExecutionDemo:
         """Set up the unified order execution system."""
         logger.info("Setting up unified order execution system...")
         
-        # In a real implementation, these would be properly configured
-        # For demo purposes, we'll create mock instances
+        # Configure real components using environment variables
+        # Ensure all required environment variables are set
         
         # Market manager configuration
         market_config = {
@@ -54,15 +54,36 @@ class UnifiedOrderExecutionDemo:
                 'crypto': {
                     'enabled': True,
                     'exchanges': [
-                        {'name': 'binance', 'credentials': 'mock_credentials'},
-                        {'name': 'coinbase', 'credentials': 'mock_credentials'}
+                        {
+                            'name': 'binance',
+                            'api_key': os.getenv('BINANCE_API_KEY'),
+                            'api_secret': os.getenv('BINANCE_API_SECRET'),
+                            'sandbox': True
+                        },
+                        {
+                            'name': 'coinbase',
+                            'api_key': os.getenv('COINBASE_API_KEY'),
+                            'api_secret': os.getenv('COINBASE_API_SECRET'),
+                            'sandbox': True
+                        }
                     ]
                 },
                 'forex': {
                     'enabled': True,
                     'brokers': [
-                        {'name': 'oanda', 'credentials': 'mock_credentials'},
-                        {'name': 'mt5', 'credentials': 'mock_credentials'}
+                        {
+                            'name': 'oanda',
+                            'api_key': os.getenv('OANDA_API_KEY'),
+                            'account_id': os.getenv('OANDA_ACCOUNT_ID'),
+                            'sandbox': True
+                        },
+                        {
+                            'name': 'mt5',
+                            'login': os.getenv('MT5_LOGIN'),
+                            'password': os.getenv('MT5_PASSWORD'),
+                            'server': os.getenv('MT5_SERVER'),
+                            'sandbox': True
+                        }
                     ]
                 }
             },
