@@ -16,17 +16,21 @@ Features:
 - Portfolio management
 
 Author: GeneBot Development Team
-Version: 1.0.0
+Version: 1.1.14
 License: MIT
 """
 
-__version__ = "1.0.0"
+__version__ = "1.1.14"
 __author__ = "GeneBot Development Team"
 __email__ = "support@genebot.ai"
 __description__ = "Advanced Multi-Market Trading Bot"
 
+# Import core components
+from .core import TradingBotOrchestrator
+
 __all__ = [
     '__version__',
     '__author__',
-    '__description__'
+    '__description__',
+    'TradingBotOrchestrator'
 ]
\ No newline at end of file
