@@ -308,7 +308,7 @@ class ValidateConfigCommand(BaseCommand):
                     self.logger.list_item(f"⚠️  {warning}", "warning")
             
             # Show info if verbose
-            if verbose and validation_result.info:
+            if verbose and hasattr(validation_result, 'info') and validation_result.info:
                 self.logger.subsection(f"Information ({len(validation_result.info)})")
                 for info in validation_result.info:
                     self.logger.list_item(f"ℹ️  {info}", "info")
@@ -320,7 +320,7 @@ class ValidateConfigCommand(BaseCommand):
                     data={
                         'errors': validation_result.errors,
                         'warnings': validation_result.warnings,
-                        'info': validation_result.info
+                        'info': getattr(validation_result, 'info', [])
                     }
                 )
             else:
@@ -339,7 +339,9 @@ class ValidateConfigCommand(BaseCommand):
             self.logger.error(f"Validation failed: {e.message}")
             return CommandResult.error(str(e.message), suggestions=e.suggestions)
         except Exception as e:
+            import traceback
             self.logger.error(f"Unexpected validation error: {str(e)}")
+            self.logger.debug(f"Traceback: {traceback.format_exc()}")
             return CommandResult.error(
                 f"Configuration validation failed: {str(e)}",
                 suggestions=[
@@ -1137,6 +1139,6 @@ class SystemValidateCommand(BaseCommand):
             for warning in result.warnings:
                 self.logger.list_item(f"⚠️  {warning}", "warning")
         
-        if verbose and result.info:
+        if verbose and hasattr(result, 'info') and result.info:
             for info in result.info:
                 self.logger.list_item(f"ℹ️  {info}", "info")
\ No newline at end of file
