@@ -80,7 +80,8 @@ class ConfigurationManager:
             else:
                 result = ConfigValidationResult()
                 result.add_error("Main bot configuration file not found")
-                result.add_suggestion("Run 'genebot init-config' to create configuration files")
+                if hasattr(result, 'add_info'):
+                    result.add_info("Run 'genebot init-config' to create configuration files")
             
             # Additional CLI-specific validations
             self._validate_cli_requirements(result)
@@ -100,12 +101,14 @@ class ConfigurationManager:
             dir_path = Path(dir_name)
             if not dir_path.exists():
                 result.add_warning(f"Required directory missing: {dir_name}")
-                result.add_suggestion(f"Create directory with 'mkdir -p {dir_name}'")
+                if hasattr(result, 'add_info'):
+                    result.add_info(f"Create directory with 'mkdir -p {dir_name}'")
         
         # Check environment file
         if not self.env_file.exists():
             result.add_error("Environment file (.env) not found")
-            result.add_suggestion("Create .env file with API credentials")
+            if hasattr(result, 'add_info'):
+                result.add_info("Create .env file with API credentials")
         else:
             # Check for placeholder values in .env
             try:
@@ -116,7 +119,8 @@ class ConfigurationManager:
                 for pattern in placeholder_patterns:
                     if pattern in env_content.lower():
                         result.add_warning("Environment file contains placeholder values")
-                        result.add_suggestion("Update .env file with actual API credentials")
+                        if hasattr(result, 'add_info'):
+                            result.add_info("Update .env file with actual API credentials")
                         break
             except Exception:
                 result.add_warning("Could not read environment file")
