@@ -79,7 +79,8 @@ except ImportError:
         
         def log_trade(self, *args, **kwargs):
             pass
-from genebot.config.logging import get_logger, LogContext
+from genebot.logging.factory import get_logger
+from genebot.logging.context import LogContext
 
 
 @dataclass
