@@ -120,7 +120,8 @@ class SystemDiagnostics:
             ]
         
         results = {}
-        overall_success = True
+        successful_connections = 0
+        total_hosts = len(hosts)
         
         for host_info in hosts:
             if isinstance(host_info, tuple):
@@ -131,14 +132,19 @@ class SystemDiagnostics:
             try:
                 socket.create_connection((host, port), timeout=5)
                 results[host] = {'success': True, 'message': f"Connected to {host}:{port}"}
+                successful_connections += 1
             except Exception as e:
                 results[host] = {'success': False, 'error': str(e), 'message': f"Failed to connect to {host}:{port}"}
-                overall_success = False
+        
+        # Consider it successful if at least half the connections work
+        overall_success = successful_connections >= (total_hosts // 2)
         
         return {
             'success': overall_success,
             'results': results,
-            'message': f"Network connectivity: {'OK' if overall_success else 'Issues detected'}"
+            'successful_connections': successful_connections,
+            'total_hosts': total_hosts,
+            'message': f"Network connectivity: {successful_connections}/{total_hosts} hosts reachable"
         }
     
     def check_ssl_certificates(self, hosts: List[str] = None) -> Dict[str, Any]:
@@ -147,12 +153,14 @@ class SystemDiagnostics:
             hosts = ['api.binance.com', 'api.oanda.com', 'api.kraken.com']
         
         results = {}
-        overall_success = True
+        successful_checks = 0
+        total_hosts = len(hosts)
         
         for host in hosts:
             try:
                 context = ssl.create_default_context()
-                with socket.create_connection((host, 443), timeout=10) as sock:
+                # Reduce timeout to avoid hanging
+                with socket.create_connection((host, 443), timeout=5) as sock:
                     with context.wrap_socket(sock, server_hostname=host) as ssock:
                         cert = ssock.getpeercert()
                         results[host] = {
@@ -161,18 +169,23 @@ class SystemDiagnostics:
                             'issuer': dict(x[0] for x in cert['issuer']),
                             'message': f"SSL certificate valid for {host}"
                         }
+                        successful_checks += 1
             except Exception as e:
                 results[host] = {
                     'success': False,
                     'error': str(e),
-                    'message': f"SSL certificate issue for {host}: {e}"
+                    'message': f"SSL certificate issue for {host}: {str(e)[:100]}..."
                 }
-                overall_success = False
+        
+        # Consider it successful if at least one SSL check passes
+        overall_success = successful_checks > 0
         
         return {
             'success': overall_success,
             'results': results,
-            'message': f"SSL certificates: {'OK' if overall_success else 'Issues detected'}"
+            'successful_checks': successful_checks,
+            'total_hosts': total_hosts,
+            'message': f"SSL certificates: {successful_checks}/{total_hosts} hosts verified"
         }
 
 
